@@ -4,19 +4,21 @@
 # suitable for unzipping at devices with small RAM,
 # micropython friendly
 
-import os, sys, zlib
+# usage:
+# ./gzip4k.py blink.bit blink.bit.gz
 
-def gzip4k(fname):
-  stream = open(fname, "rb")
+import sys, zlib
+
+def gzip4k(fname_src, fname_dst):
+  stream = open(fname_src, "rb")
   comp = zlib.compressobj(level=9, wbits=16 + 12)
-  with open(fname + ".gz", "wb") as outf:
+  with open(fname_dst, "wb") as outf:
     while 1:
       data = stream.read(1024)
       if not data:
         break
       outf.write(comp.compress(data))
     outf.write(comp.flush())
-  os.remove(fname)
 
 if __name__ == "__main__":
-  gzip4k(sys.argv[1])
+  gzip4k(sys.argv[1], sys.argv[2])
